From 258abe1a23dedc34d9379fe85565eda79f6e69d6 Mon Sep 17 00:00:00 2001
From: Monty Taylor <mordred@inaugust.com>
Date: Sun, 21 Jul 2013 21:08:11 -0700
Subject: [PATCH] Use cgit server instead of github for everything

We have a cgit server now, which means we should replace
all references to github with references to git.openstack.org.

Change-Id: I68ad1ce514fb4326c7d9940b5a84999af5b58562
---
 doc/source/custom_roles.py                            |  6 ++++--
 doc/source/devstack-gate.rst                          |  4 ++--
 doc/source/gerrit.rst                                 |  2 +-
 doc/source/git.rst                                    |  2 +-
 doc/source/irc.rst                                    |  8 ++++----
 doc/source/jeepyb.rst                                 |  2 +-
 doc/source/jenkins.rst                                |  6 +++---
 doc/source/jjb.rst                                    |  6 +++---
 doc/source/paste.rst                                  |  4 ++--
 doc/source/planet.rst                                 |  4 ++--
 doc/source/puppet.rst                                 |  2 +-
 doc/source/stackforge.rst                             |  4 ++--
 doc/source/sysadmin.rst                               |  4 ++--
 doc/source/zuul.rst                                   |  2 +-
 install_jenkins_slave.sh                              |  2 +-
 modules/gerrit/templates/gerrit.config.erb            |  2 +-
 modules/gerrit/templates/replication.config.erb       |  2 +-
 modules/jeepyb/manifests/init.pp                      |  2 +-
 modules/jenkins/manifests/job_builder.pp              |  2 +-
 modules/lodgeit/manifests/init.pp                     |  2 +-
 modules/meetbot/manifests/init.pp                     |  2 +-
 .../openstack_project/files/jenkins-pypi-mirror.yaml  |  6 +++---
 .../files/jenkins_job_builder/config/defaults.yaml    |  4 ++--
 .../files/jenkins_job_builder/config/manuals.yaml     |  4 ++--
 .../config/python-bitrot-jobs.yaml                    |  6 +++---
 .../jenkins_job_builder/config/translation-jobs.yaml  |  4 ++--
 .../files/jenkins_job_builder/config/zuul.yaml        |  2 +-
 .../files/logs/help/tempest-logs.html                 | 11 ++++++++---
 .../files/logs/help/tempest-overview.html             | 11 ++++++++---
 .../files/nodepool/scripts/prepare_node.sh            |  2 +-
 modules/openstack_project/files/pypi-mirror.yaml      |  6 +++---
 modules/openstack_project/manifests/planet.pp         |  2 +-
 modules/openstack_project/manifests/static.pp         |  2 +-
 .../templates/review.projects.yaml.erb                |  1 -
 modules/pypimirror/templates/run-mirror.sh.erb        |  2 +-
 modules/releasestatus/manifests/init.pp               |  2 +-
 modules/statusbot/manifests/init.pp                   |  2 +-
 modules/zuul/manifests/init.pp                        |  2 +-
 38 files changed, 75 insertions(+), 64 deletions(-)

diff --git a/doc/source/devstack-gate.rst b/doc/source/devstack-gate.rst
index f698157a85..81348d6d0a 100644
--- a/doc/source/devstack-gate.rst
+++ b/doc/source/devstack-gate.rst
@@ -19,11 +19,11 @@ At a Glance
   * :file:`modules/openstack_project/manifests/template.pp`
   * :file:`modules/openstack_project/manifests/devstack_launch_slave.pp`
 :Projects:
-  * http://github.com/openstack-infra/devstack-gate
+  * https://git.openstack.org/openstack-infra/devstack-gate
 :Bugs:
   * http://bugs.launchpad.net/openstack-ci
 :Resources:
-  * `Devstack-gate README <https://github.com/openstack-infra/devstack-gate/blob/master/README.md>`_
+  * `Devstack-gate README <https://git.openstack.org/cgit/openstack-infra/devstack-gate/tree/README.rst>`_
 
 Overview
 ========
diff --git a/doc/source/gerrit.rst b/doc/source/gerrit.rst
index 01d5250451..665d2a20b5 100644
--- a/doc/source/gerrit.rst
+++ b/doc/source/gerrit.rst
@@ -368,7 +368,7 @@ To rename a project:
 Developers will either need to re-clone a new copy of the repository,
 or manually update their remotes with something like::
 
-  git remote set-url origin https://github.com/$ORG/$PROJECT.git
+  git remote set-url origin https://git.openstack.org/$ORG/$PROJECT
 
 Deleting a User from Gerrit
 ---------------------------
diff --git a/doc/source/git.rst b/doc/source/git.rst
index 1d6647ff1f..f37507dcb5 100644
--- a/doc/source/git.rst
+++ b/doc/source/git.rst
@@ -11,7 +11,7 @@ At a Glance
 ===========
 
 :Hosts:
-  * http://git.openstack.org
+  * https://git.openstack.org
 :Puppet:
   * :file:`modules/cgit`
   * :file:`modules/openstack_project/manifests/git.pp`
diff --git a/doc/source/irc.rst b/doc/source/irc.rst
index c4283f7df8..4aa77232da 100644
--- a/doc/source/irc.rst
+++ b/doc/source/irc.rst
@@ -26,9 +26,9 @@ At a Glance
 :Projects:
   * http://wiki.debian.org/MeetBot
   * http://sourceforge.net/projects/supybot/
-  * https://github.com/openstack-infra/meetbot
-  * https://github.com/openstack-infra/gerritbot
-  * https://github.com/openstack-infra/statusbot
+  * https://git.openstack.org/cgit/openstack-infra/meetbot
+  * https://git.openstack.org/cgit/openstack-infra/gerritbot
+  * https://git.openstack.org/cgit/openstack-infra/statusbot
 :Bugs:
   * http://bugs.launchpad.net/openstack-ci
 
@@ -63,7 +63,7 @@ Meetbot
 -------
 
 The OpenStack Infrastructure Meetbot fork can be found at
-https://github.com/openstack-infra/meetbot. Manual installation of the Meetbot
+https://git.openstack.org/cgit/openstack-infra/meetbot. Manual installation of the Meetbot
 plugin is straightforward and documented in that repository's README.
 OpenStack Infrastructure installs and configures Meetbot through Puppet.
 
diff --git a/doc/source/jeepyb.rst b/doc/source/jeepyb.rst
index 230a61874b..2a4a58b96d 100644
--- a/doc/source/jeepyb.rst
+++ b/doc/source/jeepyb.rst
@@ -23,7 +23,7 @@ At a Glance
   * :file:`modules/openstack_project/templates/review.projects.yaml.erb`
   * :file:`modules/openstack_project/files/pypi-mirror.yaml`
 :Projects:
-  * http://github.com/openstack-infra/jeepyb
+  * https://git.openstack.org/cgit/openstack-infra/jeepyb
 :Bugs:
   * http://bugs.launchpad.net/openstack-ci
 
diff --git a/doc/source/jenkins.rst b/doc/source/jenkins.rst
index db089fb4d6..2bbfd8d8ad 100644
--- a/doc/source/jenkins.rst
+++ b/doc/source/jenkins.rst
@@ -83,9 +83,9 @@ Devstack Gate
 OpenStack integration testing is performed by the devstack gate test
 framework. This framework runs the devstack exercises and Tempest
 smoketests against a devstack install on single use cloud servers. The
-devstack gate source can be found on `Github
-<https://github.com/openstack-infra/devstack-gate>`_ and the `Readme
-<https://github.com/openstack-infra/devstack-gate/blob/master/README.rst>`_
+devstack gate source can be found on `git.openstack.org
+<https://git.openstack.org/cgit/openstack-infra/devstack-gate>`_ and the `Readme
+<https://git.openstack.org/cgit/openstack-infra/devstack-gate/tree/README.rst>`_
 describes the process of using devstack gate to run your own devstack
 based tests.
 
diff --git a/doc/source/jjb.rst b/doc/source/jjb.rst
index 27d6061769..74edb20057 100644
--- a/doc/source/jjb.rst
+++ b/doc/source/jjb.rst
@@ -19,7 +19,7 @@ At a Glance
 :Configuration:
   * :file:`modules/openstack_project/files/jenkins_job_builder/config/`
 :Projects:
-  * http://github.com/openstack-infra/jenkins-job-builder
+  * https://git.openstack.org/cgit/openstack-infra/jenkins-job-builder
 :Bugs:
   * http://bugs.launchpad.net/openstack-ci
 :Resources:
@@ -70,8 +70,8 @@ Example defaults config:
 
          <p>If you would like to make changes to this job, please see:
 
-           <a href="https://github.com/openstack-infra/config">
-             https://github.com/openstack-infra/config
+           <a href="https://git.openstack.org/cgit/openstack-infra/config">
+             https://git.openstack.org/cgit/openstack-infra/config
            </a>
 
          In modules/openstack_project/files/jenkins_jobs
diff --git a/doc/source/paste.rst b/doc/source/paste.rst
index 48a74db24a..d48da0fc40 100644
--- a/doc/source/paste.rst
+++ b/doc/source/paste.rst
@@ -19,7 +19,7 @@ At a Glance
   * :file:`modules/lodgeit`
   * :file:`modules/openstack_project/manifests/paste.pp`
 :Projects:
-  * http://github.com/openstack-infra/lodgeit
+  * https://git.openstack.org/cgit/openstack-infra/lodgeit
   * https://bitbucket.org/dcolish/lodgeit-main
   * http://www.pocoo.org/projects/lodgeit/
 :Bugs:
@@ -29,7 +29,7 @@ Overview
 ========
 
 For OpenStack we use `a fork
-<https://github.com/openstack-infra/lodgeit>`_ of lodgeit which is
+<https://git.openstack.org/cgit/openstack-infra/lodgeit>`_ of lodgeit which is
 based on one with bugfixes maintained by `dcolish
 <https://bitbucket.org/dcolish/lodgeit-main>`_ but adds back missing
 anti-spam features required by Openstack.
diff --git a/doc/source/planet.rst b/doc/source/planet.rst
index 2386e1750f..73aa917b93 100644
--- a/doc/source/planet.rst
+++ b/doc/source/planet.rst
@@ -18,9 +18,9 @@ At a Glance
   * :file:`modules/planet`
   * :file:`modules/openstack_project/manifests/planet.pp`
 :Configuration:
-  * https://github.com/openstack/openstack-planet/blob/master/planet.ini
+  * https://git.openstack.org/cgit/openstack/openstack-planet/tree/planet.ini
 :Projects:
-  * https://github.com/openstack/openstack-planet
+  * https://git.openstack.org/cgit/openstack/openstack-planet
   * http://www.intertwingly.net/code/venus/
 :Bugs:
   * http://bugs.launchpad.net/openstack-ci
diff --git a/doc/source/puppet.rst b/doc/source/puppet.rst
index 6be355373b..a27544a3b9 100644
--- a/doc/source/puppet.rst
+++ b/doc/source/puppet.rst
@@ -43,7 +43,7 @@ over the preferences file:
 
 .. code-block:: bash
 
-   git clone git://github.com/openstack-infra/config.git /opt/config/production
+   git clone https://git.openstack.org/openstack-infra/config /opt/config/production
    cp /opt/config/production/modules/openstack_project/files/00-puppet.pref /etc/apt/preferences.d/
 
 Then we can add the repo and install the packages, we'll also install the hiera
diff --git a/doc/source/stackforge.rst b/doc/source/stackforge.rst
index 9c0696ec82..874d096acf 100644
--- a/doc/source/stackforge.rst
+++ b/doc/source/stackforge.rst
@@ -47,7 +47,7 @@ Create a new StackForge Project with Puppet
 OpenStack uses Puppet and a management script to create Gerrit projects
 with simple changes to the openstack-infra/config repository. To start make
 sure you have cloned the openstack-infra/config repository
-``git clone https://github.com/openstack-infra/config``.
+``git clone https://git.openstack.org/openstack-infra/config``.
 
 First you need to add your StackForge project to the master project
 list. Edit
@@ -243,7 +243,7 @@ new file will allow you to use ``git review``.
 The basic process is clone from stackforge, add file, push to Gerrit,
 review and approve.::
 
-  git clone https://github.com/stackforge/project-name
+  git clone https://git.openstack.org/stackforge/project-name
   cd project-name
   git checkout -b add-gitreview
   cat > .gitreview <<EOF
diff --git a/doc/source/sysadmin.rst b/doc/source/sysadmin.rst
index a7041ae771..354b6dd9e8 100644
--- a/doc/source/sysadmin.rst
+++ b/doc/source/sysadmin.rst
@@ -14,7 +14,7 @@ collaborate on code reviews.
 The configuration of every system operated by the infrastructure team
 is managed by Puppet in a single Git repository:
 
-  https://github.com/openstack-infra/config
+  https://git.openstack.org/cgit/openstack-infra/config
 
 All system configuration should be encoded in that repository so that
 anyone may propose a change in the running configuration to Gerrit.
@@ -65,7 +65,7 @@ repo::
 
   sudo su -
   apt-get install git
-  git clone https://github.com/openstack-infra/config
+  git clone https://git.openstack.org/openstack-infra/config
   cd config
 
 Then copy the etherpad node definition from manifests/site.pp to a new
diff --git a/doc/source/zuul.rst b/doc/source/zuul.rst
index d900a04224..d6d5114465 100644
--- a/doc/source/zuul.rst
+++ b/doc/source/zuul.rst
@@ -23,7 +23,7 @@ At a Glance
   * :file:`modules/openstack_project/files/zuul/layout.yaml`
 :Projects:
   * http://launchpad.net/zuul
-  * http://github.com/openstack-infra/zuul
+  * https://git.openstack.org/cgit/openstack-infra/zuul
 :Bugs:
   * http://bugs.launchpad.net/zuul
 :Resources:
diff --git a/install_jenkins_slave.sh b/install_jenkins_slave.sh
index 51e2acf7a6..740301ff0f 100755
--- a/install_jenkins_slave.sh
+++ b/install_jenkins_slave.sh
@@ -45,7 +45,7 @@ else #defaults to Ubuntu
 
 fi
 
-git clone https://github.com/openstack-infra/config
+git clone https://git.openstack.org/openstack-infra/config
 bash config/install_modules.sh
 
 puppet apply --modulepath=`pwd`/config/modules:/etc/puppet/modules -e 'node default {class { "openstack_project::bare_slave": install_users => false }}'
diff --git a/modules/gerrit/templates/gerrit.config.erb b/modules/gerrit/templates/gerrit.config.erb
index ae9c8f6420..4ce7859c24 100644
--- a/modules/gerrit/templates/gerrit.config.erb
+++ b/modules/gerrit/templates/gerrit.config.erb
@@ -1,5 +1,5 @@
 # This file is managed by puppet.
-# https://github.com/openstack-infra/config
+# https://git.openstack.org/cgit/openstack-infra/config
 
 [gerrit]
 	basePath = git
diff --git a/modules/gerrit/templates/replication.config.erb b/modules/gerrit/templates/replication.config.erb
index c2c918041a..3ab3283e6a 100644
--- a/modules/gerrit/templates/replication.config.erb
+++ b/modules/gerrit/templates/replication.config.erb
@@ -1,5 +1,5 @@
 # This file is managed by puppet.
-# https://github.com/openstack-infra/config
+# https://git.openstack.org/cgit/openstack-infra/config
 
 <% replication.each do |replication| -%>
 [remote "<%= replication['name'] %>"]
diff --git a/modules/jeepyb/manifests/init.pp b/modules/jeepyb/manifests/init.pp
index 6d9fc3b2a9..ae0a623f73 100644
--- a/modules/jeepyb/manifests/init.pp
+++ b/modules/jeepyb/manifests/init.pp
@@ -1,7 +1,7 @@
 # == Class: jeepyb
 #
 class jeepyb (
-  $git_source_repo = 'https://github.com/openstack-infra/jeepyb.git',
+  $git_source_repo = 'https://git.openstack.org/openstack-infra/jeepyb',
 ) {
   include mysql::python
 
diff --git a/modules/jenkins/manifests/job_builder.pp b/modules/jenkins/manifests/job_builder.pp
index b732389b12..85e942c063 100644
--- a/modules/jenkins/manifests/job_builder.pp
+++ b/modules/jenkins/manifests/job_builder.pp
@@ -24,7 +24,7 @@ class jenkins::job_builder (
     ensure   => latest,
     provider => git,
     revision => 'master',
-    source   => 'https://github.com/openstack-infra/jenkins-job-builder.git',
+    source   => 'https://git.openstack.org/openstack-infra/jenkins-job-builder',
   }
 
   exec { 'install_jenkins_job_builder':
diff --git a/modules/lodgeit/manifests/init.pp b/modules/lodgeit/manifests/init.pp
index 9237945636..c2da8066bc 100644
--- a/modules/lodgeit/manifests/init.pp
+++ b/modules/lodgeit/manifests/init.pp
@@ -48,7 +48,7 @@ class lodgeit {
   vcsrepo { '/tmp/lodgeit-main':
     ensure   => latest,
     provider => git,
-    source   => 'https://github.com/openstack-infra/lodgeit.git',
+    source   => 'https://git.openstack.org/openstack-infra/lodgeit',
   }
 
 # create initial git DB backup location
diff --git a/modules/meetbot/manifests/init.pp b/modules/meetbot/manifests/init.pp
index b19995cd78..ddaceb735e 100644
--- a/modules/meetbot/manifests/init.pp
+++ b/modules/meetbot/manifests/init.pp
@@ -4,7 +4,7 @@ class meetbot {
   vcsrepo { '/opt/meetbot':
     ensure   => latest,
     provider => git,
-    source   => 'https://github.com/openstack-infra/meetbot.git',
+    source   => 'https://git.openstack.org/openstack-infra/meetbot',
   }
 
   user { 'meetbot':
diff --git a/modules/openstack_project/files/jenkins-pypi-mirror.yaml b/modules/openstack_project/files/jenkins-pypi-mirror.yaml
index d18ca1d3f0..8a970c5a1a 100644
--- a/modules/openstack_project/files/jenkins-pypi-mirror.yaml
+++ b/modules/openstack_project/files/jenkins-pypi-mirror.yaml
@@ -1,15 +1,15 @@
 # This file is managed by puppet.
-# https://github.com/openstack-infra/config
+# https://git.openstack.org/cgit/openstack-infra/config
 
 cache-root: /home/jenkins/pypimirror/cache
 
 mirrors:
   - name: openstack
     projects:
-      - https://github.com/openstack/requirements
+      - git://git.openstack.org/openstack/requirements
     output: /home/jenkins/pypimirror/mirror/openstack
 
   - name: openstack-infra
     projects:
-      - https://github.com/openstack-infra/config
+      - git://git.openstack.org/openstack-infra/config
     output: /home/jenkins/pypimirror/mirror/openstack-infra
diff --git a/modules/openstack_project/files/jenkins_job_builder/config/defaults.yaml b/modules/openstack_project/files/jenkins_job_builder/config/defaults.yaml
index 4c07636f01..f1b48ddd5b 100644
--- a/modules/openstack_project/files/jenkins_job_builder/config/defaults.yaml
+++ b/modules/openstack_project/files/jenkins_job_builder/config/defaults.yaml
@@ -7,8 +7,8 @@
 
       <p>If you would like to make changes to this job, please see:
 
-        <a href="https://github.com/openstack-infra/config">
-          https://github.com/openstack-infra/config
+        <a href="https://git.openstack.org/cgit/openstack-infra/config">
+          https://git.openstack.org/cgit/openstack-infra/config
         </a>
 
       In modules/openstack_project/files/jenkins_job_builder/config
diff --git a/modules/openstack_project/files/jenkins_job_builder/config/manuals.yaml b/modules/openstack_project/files/jenkins_job_builder/config/manuals.yaml
index df00e3125d..36c19d8921 100644
--- a/modules/openstack_project/files/jenkins_job_builder/config/manuals.yaml
+++ b/modules/openstack_project/files/jenkins_job_builder/config/manuals.yaml
@@ -353,11 +353,11 @@
       - console-log
 
 # in zuul/layout.yaml specified to only run against master branch.
-# The old jenkins config polled github every 5 minutes and was also triggered
+# The old jenkins config polled git every 5 minutes and was also triggered
 # whenever a SNAPSHOT dependency was built. I have not configured that trigger
 # here as being in the Zuul post queue may not play nice with that.
 #
-# We can use the github and snapshot dependency triggers if that is preferable.
+# We can use the git and snapshot dependency triggers if that is preferable.
 - job:
     name: openstack-ha-guide
     project-type: maven
diff --git a/modules/openstack_project/files/jenkins_job_builder/config/python-bitrot-jobs.yaml b/modules/openstack_project/files/jenkins_job_builder/config/python-bitrot-jobs.yaml
index d0f3d19c5e..4f5d7a303a 100644
--- a/modules/openstack_project/files/jenkins_job_builder/config/python-bitrot-jobs.yaml
+++ b/modules/openstack_project/files/jenkins_job_builder/config/python-bitrot-jobs.yaml
@@ -26,7 +26,7 @@
 
     scm:
       - git:
-          url: 'git://github.com/{github-org}/{name}.git'
+          url: 'git://git.openstack.org/{github-org}/{name}'
           branches:
             - 'origin/{branch}'
 
@@ -61,7 +61,7 @@
 
     scm:
       - git:
-          url: 'git://github.com/{github-org}/{name}.git'
+          url: 'git://git.openstack.org/{github-org}/{name}'
           branches:
             - 'origin/{branch}'
 
@@ -89,7 +89,7 @@
 
     scm:
       - git:
-          url: 'git://github.com/{github-org}/{name}.git'
+          url: 'git://git.openstack.org/{github-org}/{name}'
           branches:
             - 'origin/{branch}'
 
diff --git a/modules/openstack_project/files/jenkins_job_builder/config/translation-jobs.yaml b/modules/openstack_project/files/jenkins_job_builder/config/translation-jobs.yaml
index fa25bdaa87..89776ea44f 100644
--- a/modules/openstack_project/files/jenkins_job_builder/config/translation-jobs.yaml
+++ b/modules/openstack_project/files/jenkins_job_builder/config/translation-jobs.yaml
@@ -27,7 +27,7 @@
 
     scm:
       - git:
-          url: 'git://github.com/{github-org}/{name}.git'
+          url: 'git://git.openstack.org/{github-org}/{name}'
           branches:
             - 'origin/master'
 
@@ -62,7 +62,7 @@
 
     scm:
       - git:
-          url: 'git://github.com/openstack/openstack-manuals.git'
+          url: 'git://git.openstack.org/openstack/openstack-manuals'
           branches:
             - 'origin/master'
 
diff --git a/modules/openstack_project/files/jenkins_job_builder/config/zuul.yaml b/modules/openstack_project/files/jenkins_job_builder/config/zuul.yaml
index a4e22b5d00..2cb0de0df8 100644
--- a/modules/openstack_project/files/jenkins_job_builder/config/zuul.yaml
+++ b/modules/openstack_project/files/jenkins_job_builder/config/zuul.yaml
@@ -52,7 +52,7 @@
 
     scm:
       - git:
-          url: 'git://github.com/openstack-infra/zuul.git'
+          url: 'git://git.openstack.org/openstack-infra/zuul'
           branches:
             - 'origin/master'
 
diff --git a/modules/openstack_project/files/logs/help/tempest-logs.html b/modules/openstack_project/files/logs/help/tempest-logs.html
index 5f73394b80..7316870c9e 100644
--- a/modules/openstack_project/files/logs/help/tempest-logs.html
+++ b/modules/openstack_project/files/logs/help/tempest-logs.html
@@ -44,7 +44,12 @@
 </p>
 <h2>About this Help</h2>
 <p>
-  This help file is part of the openstack-infra/config project, and
-  can be updated by pushing a review request to
-  <a href="https://github.com/openstack-infra/config/tree/master/modules/openstack_project/files/logs/help">https://github.com/openstack-infra/config/tree/master/modules/openstack_project/files/logs/help</a>
+  This help file is part of the
+  <a href="https://git.openstack.org/cgit/openstack-infra/config">
+      openstack-infra/config</a>
+  project, and can be found at
+  <a href="https://git.openstack.org/cgit/openstack-infra/config/tree/modules/openstack_project/files/logs/help/tempest_logs.html">
+      modules/openstack_project/files/logs/help/tempest_logs.html
+  </a>.
+  The file can be updated via the standard OpenStack Gerrit Review process.
 </p>
diff --git a/modules/openstack_project/files/logs/help/tempest-overview.html b/modules/openstack_project/files/logs/help/tempest-overview.html
index edc7c343b9..32cdc95c1a 100644
--- a/modules/openstack_project/files/logs/help/tempest-overview.html
+++ b/modules/openstack_project/files/logs/help/tempest-overview.html
@@ -45,7 +45,12 @@ job. The basic flow of the file goes as follows:
 </p>
 <h2>About this Help</h2>
 <p>
-  This help file is part of the <a href="https://github.com/openstack-infra/config">openstack-infra/config</a> project, and
-  can be updated by pushing a review request to
-  <a href="https://github.com/openstack-infra/config/tree/master/modules/openstack_project/files/logs/help">https://github.com/openstack-infra/config/tree/master/modules/openstack_project/files/logs/help</a>
+  This help file is part of the
+  <a href="https://git.openstack.org/cgit/openstack-infra/config">
+      openstack-infra/config</a>
+  project, and can be found at
+  <a href="https://git.openstack.org/cgit/openstack-infra/config/tree/modules/openstack_project/files/logs/help/tempest_overview.html">
+      modules/openstack_project/files/logs/help/tempest_overview.html
+  </a>.
+  The file can be updated via the standard OpenStack Gerrit Review process.
 </p>
diff --git a/modules/openstack_project/files/nodepool/scripts/prepare_node.sh b/modules/openstack_project/files/nodepool/scripts/prepare_node.sh
index 5457663083..6322ffae29 100755
--- a/modules/openstack_project/files/nodepool/scripts/prepare_node.sh
+++ b/modules/openstack_project/files/nodepool/scripts/prepare_node.sh
@@ -19,7 +19,7 @@
 HOSTNAME=$1
 
 sudo hostname $1
-wget https://raw.github.com/openstack-infra/config/master/install_puppet.sh
+wget https://git.openstack.org/cgit/openstack-infra/config/plain/install_puppet.sh
 sudo bash -xe install_puppet.sh
 sudo git clone https://review.openstack.org/p/openstack-infra/config.git \
     /root/config
diff --git a/modules/openstack_project/files/pypi-mirror.yaml b/modules/openstack_project/files/pypi-mirror.yaml
index 3ed9175000..341dc31258 100644
--- a/modules/openstack_project/files/pypi-mirror.yaml
+++ b/modules/openstack_project/files/pypi-mirror.yaml
@@ -1,15 +1,15 @@
 # This file is managed by puppet.
-# https://github.com/openstack-infra/config
+# https://git.openstack.org/cgit/openstack-infra/config
 
 cache-root: /var/cache/pypimirror
 
 mirrors:
   - name: openstack
     projects:
-      - https://github.com/openstack/requirements
+      - git://git.openstack.org/openstack/requirements
     output: /var/lib/pypimirror/openstack
 
   - name: openstack-infra
     projects:
-      - https://github.com/openstack-infra/config
+      - git://git.openstack.org/openstack-infra/config
     output: /var/lib/pypimirror/openstack-infra
diff --git a/modules/openstack_project/manifests/planet.pp b/modules/openstack_project/manifests/planet.pp
index ea1d26443e..cb7446368c 100644
--- a/modules/openstack_project/manifests/planet.pp
+++ b/modules/openstack_project/manifests/planet.pp
@@ -10,6 +10,6 @@ class openstack_project::planet (
   include ::planet
 
   planet::site { 'openstack':
-    git_url => 'https://github.com/openstack/openstack-planet.git',
+    git_url => 'git://git.openstack.org/openstack/openstack-planet',
   }
 }
diff --git a/modules/openstack_project/manifests/static.pp b/modules/openstack_project/manifests/static.pp
index ea54c4173c..5dad0fcbe8 100644
--- a/modules/openstack_project/manifests/static.pp
+++ b/modules/openstack_project/manifests/static.pp
@@ -290,7 +290,7 @@ class openstack_project::static (
   include reviewday
 
   reviewday::site { 'reviewday':
-    git_url                       => 'https://github.com/openstack-infra/reviewday.git',
+    git_url                       => 'git://git.openstack.org/openstack-infra/reviewday',
     serveradmin                   => 'webmaster@openstack.org',
     httproot                      => '/srv/static/reviewday',
     gerrit_url                    => 'review.openstack.org',
diff --git a/modules/openstack_project/templates/review.projects.yaml.erb b/modules/openstack_project/templates/review.projects.yaml.erb
index 365231fdda..5e3e297a84 100644
--- a/modules/openstack_project/templates/review.projects.yaml.erb
+++ b/modules/openstack_project/templates/review.projects.yaml.erb
@@ -42,7 +42,6 @@
 - project: openstack-infra/nose-html-output
 - project: openstack-infra/publications
   description: "OpenStack Infra Team conference presentations and papers"
-  upstream: git://github.com/openstack-ci/publications.git
 - project: openstack-infra/puppet-apparmor
 - project: openstack-infra/puppet-dashboard
 - project: openstack-infra/puppet-vcsrepo
diff --git a/modules/pypimirror/templates/run-mirror.sh.erb b/modules/pypimirror/templates/run-mirror.sh.erb
index 908acd3378..9f9d04065c 100644
--- a/modules/pypimirror/templates/run-mirror.sh.erb
+++ b/modules/pypimirror/templates/run-mirror.sh.erb
@@ -1,5 +1,5 @@
 #!/bin/bash -e
 # This file is managed by puppet.
-# https://github.com/openstack-infra/config
+# https://git.openstack.org/cgit/openstack-infra/config
 
 /usr/local/bin/run-mirror -c <%= mirror_config %> >> <%= log_filename %>
diff --git a/modules/releasestatus/manifests/init.pp b/modules/releasestatus/manifests/init.pp
index f16afe743f..0c68a821b4 100644
--- a/modules/releasestatus/manifests/init.pp
+++ b/modules/releasestatus/manifests/init.pp
@@ -111,7 +111,7 @@ class releasestatus (
   vcsrepo { '/var/lib/releasestatus/releasestatus':
     ensure   => latest,
     provider => git,
-    source   => 'https://github.com/openstack-infra/releasestatus.git',
+    source   => 'https://git.openstack.org/openstack-infra/releasestatus',
     revision => 'master',
     require  => File['/var/lib/releasestatus'],
   }
diff --git a/modules/statusbot/manifests/init.pp b/modules/statusbot/manifests/init.pp
index c12c960b9e..546d6a1839 100644
--- a/modules/statusbot/manifests/init.pp
+++ b/modules/statusbot/manifests/init.pp
@@ -29,7 +29,7 @@ class statusbot(
     ensure   => latest,
     provider => git,
     revision => 'master',
-    source   => 'https://github.com/openstack-infra/statusbot.git',
+    source   => 'https://git.openstack.org/openstack-infra/statusbot',
   }
 
   exec { 'install_statusbot' :
diff --git a/modules/zuul/manifests/init.pp b/modules/zuul/manifests/init.pp
index 04ca40c78a..5e805a8947 100644
--- a/modules/zuul/manifests/init.pp
+++ b/modules/zuul/manifests/init.pp
@@ -27,7 +27,7 @@ class zuul (
   $zuul_ssh_private_key = '',
   $url_pattern = '',
   $status_url = "https://${::fqdn}/",
-  $git_source_repo = 'https://github.com/openstack-infra/zuul.git',
+  $git_source_repo = 'https://git.openstack.org/openstack-infra/zuul',
   $push_change_refs = false,
   $revision = 'master',
   $statsd_host = ''
diff --git a/doc/source/custom_roles.py b/doc/source/custom_roles.py
index 803864b600..e1df48d5f3 100644
--- a/doc/source/custom_roles.py
+++ b/doc/source/custom_roles.py
@@ -21,9 +21,10 @@
 
 from docutils import nodes
 
+
 def file_role(name, rawtext, text, lineno, inliner,
               options={}, content=[]):
     """Link a local path to a Github file view.
 
     Returns 2 part tuple containing list of nodes to insert into the
     document and a list of system messages.  Both are allowed to be
@@ -38,7 +39,8 @@ def file_role(name, rawtext, text, lineno, inliner,
     :param content: The directive content for customization.
     """
 
-    ref = 'https://github.com/openstack-infra/config/blob/master/%s' % text
+    ref = ('https://git.openstack.org/cgit/openstack-infra/config/tree/%s'
+           % text)
     node = nodes.reference(rawtext, text, refuri=ref, **options)
     return [node], []
 
@@ -21,9 +21,10 @@
 def file_role(name, rawtext, text, lineno, inliner,
               options={}, content=[]):
-    """Link a local path to a Github file view.
+    """Link a local path to a cgit file view.
 
     Returns 2 part tuple containing list of nodes to insert into the